* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [API Updates](https://help.sap.com/docs/leanix/ea/api-updates)
  * Self-Built Software Discovery API: Asynchronous Pro…
